@@ -39,6 +39,10 @@ has 'service' => (
     handles  => [ 'get', 'is_locked', 'lock', 'unlock' ]
 );
 
+__PACKAGE__->meta->make_immutable;
+
+no Moose;
+
 1;
 
 __END__
