@@ -12,6 +12,10 @@ has 'value' => (
     required => 1,
 );
 
+__PACKAGE__->meta->make_immutable;
+
+no Moose;
+
 sub get { (shift)->value }
 
 1;
